@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 from django.core.exceptions import ValidationError
 from django.db import models
@@ -62,36 +62,36 @@ class OrderStatus(BaseOrderStatus):
     Required choices are NEW, CREATED, COMPLETED and REFUNDED.
     """
 
-    NEW = 'NEW', _("New")  # Order with reference created, items are in the basket.
-    CREATED = 'CREATED', _("Created")  # Created with items and pending payment.
-    HOLD = 'HOLD', _("Hold")  # Stock reduced but still awaiting payment.
-    FAILED = 'FAILED', _("Failed")  # Payment failed, retry is available.
-    CANCELLED = 'CANCELLED', _("Cancelled")  # Cancelled by seller, stock increased.
-    PROCESSING = 'PROCESSING', _("Processing")  # Payment confirmed, processing order.
-    SHIPPED = 'SHIPPED', _("Shipped")  # Shipped to customer.
-    COMPLETED = 'COMPLETED', _("Completed")  # Completed and received by customer.
-    REFUNDED = 'REFUNDED', _("Refunded")  # Fully refunded by seller.
+    NEW = "NEW", _("New")  # Order with reference created, items are in the basket.
+    CREATED = "CREATED", _("Created")  # Created with items and pending payment.
+    HOLD = "HOLD", _("Hold")  # Stock reduced but still awaiting payment.
+    FAILED = "FAILED", _("Failed")  # Payment failed, retry is available.
+    CANCELLED = "CANCELLED", _("Cancelled")  # Cancelled by seller, stock increased.
+    PROCESSING = "PROCESSING", _("Processing")  # Payment confirmed, processing order.
+    SHIPPED = "SHIPPED", _("Shipped")  # Shipped to customer.
+    COMPLETED = "COMPLETED", _("Completed")  # Completed and received by customer.
+    REFUNDED = "REFUNDED", _("Refunded")  # Fully refunded by seller.
 
     @classmethod
-    def get_payable(cls) -> list:
+    def get_payable(cls) -> list[Any]:
         """
         Returns default payable statuses.
         """
         return [cls.CREATED, cls.HOLD, cls.FAILED]
 
     @classmethod
-    def get_transitions(cls) -> dict:
+    def get_transitions(cls) -> dict[str, list[Any]]:
         """
         Returns default status transitions.
         """
         return {
-            'NEW': [cls.CREATED],
-            'CREATED': [cls.HOLD, cls.FAILED, cls.CANCELLED, cls.PROCESSING],
-            'HOLD': [cls.FAILED, cls.CANCELLED, cls.PROCESSING],
-            'FAILED': [cls.CANCELLED, cls.PROCESSING],
-            'CANCELLED': [],
-            'PROCESSING': [cls.SHIPPED, cls.COMPLETED, cls.REFUNDED],
-            'SHIPPED': [cls.COMPLETED, cls.REFUNDED],
-            'COMPLETED': [cls.REFUNDED],
-            'REFUNDED': [],
+            "NEW": [cls.CREATED],
+            "CREATED": [cls.HOLD, cls.FAILED, cls.CANCELLED, cls.PROCESSING],
+            "HOLD": [cls.FAILED, cls.CANCELLED, cls.PROCESSING],
+            "FAILED": [cls.CANCELLED, cls.PROCESSING],
+            "CANCELLED": [],
+            "PROCESSING": [cls.SHIPPED, cls.COMPLETED, cls.REFUNDED],
+            "SHIPPED": [cls.COMPLETED, cls.REFUNDED],
+            "COMPLETED": [cls.REFUNDED],
+            "REFUNDED": [],
         }
